@@ -167,6 +167,8 @@ class Bitpin:
 
         if 200 <= response.status_code < 300:
             try:
+                if response.request.method.lower() == 'delete':
+                    return
                 r_json: t.Dict = response.json()
             except Exception as e:
                 raise JSONDecodingError(func_name, e, additional)
@@ -291,16 +293,7 @@ class Bitpin:
 
         headers = self.__make_headers(func_name, auth)
 
-        if method.upper() == 'GET':
-            return self.__request('GET', url, headers, params, data, json_data)
-        elif method.upper() == 'POST':
-            return self.__request('POST', url, headers, params, data, json_data)
-        else:
-            raise RequestsExceptions(
-                func_name,
-                'Invalid method',
-                f_args=f_args
-            )
+        return self.__request(method.upper(), url, headers, params, data, json_data)
 
     def set_token(self, token: str):
         """
